@@ -1,6 +1,6 @@
 #' Find Common Objects from Vectors
 #'
-#' @param x must be list
+#' @param ... must be several vectors
 #'
 #' @return common objects
 #' @export
@@ -10,12 +10,10 @@
 #' x1=c('a','e','d')
 #' x2=c('a','c','e')
 #' x3=c('a','e','j','d')
-#' x=list(x1,x2,x3)
-#' common(x)
+#' common(x1,x2,x3)
 #' 
-common <- function(x){
-    if (is.data.frame(x)) stop('x must be list')
-    if (!is.list(x)) stop('x must be list')
+common <- function(...){
+    x=list(...)
     for (i in 1:length(x)) {
         if (i==1){
             common = unlist(x[i])
